import bcrypt from "bcrypt";
import { Request, Response } from "express";
import jwt from "jsonwebtoken";
import Employee from "../db/models/Employee";
import CheckIn from "../db/models/CheckIn";
import Boat from "../db/models/Boat";
import envVars from "../config";

//log in
const authLoginController = async (req: Request, res: Response) => {
  try {
    const { email, password } = req.body;

    const employee = await Employee.findOne({
      attributes: ["email", "password", "role"],
      where: {
        email: email,
      },
    });

    if (!employee) {
      return res.status(401).json({ success: false, error: "invalidEmail" });
    }

    const isPasswordCorrect = await bcrypt.compare(password, employee.password);

    if (isPasswordCorrect) {
      const payload = {
        email: employee.email,
        role: employee.role,
      };

      const token = jwt.sign(payload, envVars.JWT_SECRET);

      return res.cookie("token", token).json({ success: true });
    } else {
      return res.status(401).json({ success: false, error: "invalidPassword" });
    }
  } catch (error) {
    console.error("server error: ", error.message);
    return res.status(500).json({ success: false, error: "serverError" });
  }
};

//create log entry
const createLogEntry = async (req: Request, res: Response) => {

  try{
    
    const logEntry = req.body;
    
    const boatid = Boat.findByPk(logEntry.boatID);

    //get status of boat
    const bootAvailability = (await boatid).status;


    //if boat is not available => it's locked
    if(!(bootAvailability === true)) {
      return res.status(409).json({ success: false, error: "BoatLocked" });
    };


    const newLogEntry = await CheckIn.create(logEntry);

    return res.status(201).json({
      success: true,
      account: {
        startTime: newLogEntry.startTime,
        estimatedEndTime: newLogEntry.estimatedEndTime,
        email: newLogEntry.email,
        firstName: newLogEntry.firstName,
        lastName: newLogEntry.lastName,
        additionalClients: newLogEntry.additionalClients,
        boatID: newLogEntry.boatID,
        },
      });
  } catch (error) {
    console.error(error.message);
    return res.status(500).json({ success: false, error: "serverError" });
  }
};


const authControllers = {
  authLoginController,
  createLogEntry,
};


export default authControllers;
