import { Router } from "express";
import { body } from "express-validator";
import handleValidationResult from "../middleware/handleValidationResult";
import authControllers from "../controllers/auth.controllers";

const authRouter = Router();

//log in route
authRouter.post(
  "/api/login/",
  body("email").isEmail().normalizeEmail(),
  body("password").not().isEmpty(),
  handleValidationResult,
  authControllers.authLoginController
);

//create new log entry route
authRouter.post(
  "/api/logentry/",
  //isISO8601() checks if string is a valid date+time
  body("startTime").isISO8601(),
  body("estimatedEndTime").isISO8601(),
  body("email").isEmail().normalizeEmail(),
  body("firstName").not().isEmpty(),
  body("lastName").not().isEmpty(),
  body("boatID").isUUID(),
  handleValidationResult,
  authControllers.createLogEntry
);


export default authRouter;
